package Bundle::OS2_default1;

$VERSION = '1.01';

1;

=head1 NAME

Bundle::OS2_default1 - Modules to install first for OS/2 binary distribution

=head1 SYNOPSIS

  perl -MCPAN -e "install Bundle::OS2_default1"

=head1 CONTENTS

Data::Flow

Term::ReadKey

Curses

MD5			- to get libnet

GD

FreezeThaw

=cut

